@@ -28,7 +28,7 @@ else:
 
 
 __all__ = ["tabulate", "tabulate_formats", "simple_separated_format"]
-__version__ = "0.7.1"
+__version__ = "0.7.2"
 
 
 Line = namedtuple("Line", ["begin", "hline", "sep", "end"])
@@ -92,7 +92,7 @@ def _pipe_line_with_colons(colwidths, colaligns):
     """Return a horizontal line with optional colons to indicate column's
     alignment (as in `pipe` output format)."""
     segments = [_pipe_segment_with_colons(a, w) for a, w in zip(colaligns, colwidths)]
-    return u"|" + u"|".join(segments) + u"|"
+    return "|" + "|".join(segments) + "|"
 
 
 def _mediawiki_row_with_attrs(separator, cell_values, colwidths, colaligns):
@@ -198,7 +198,7 @@ def simple_separated_format(separator):
     """Construct a simple TableFormat with columns separated by a separator.
 
     >>> tsv = simple_separated_format("\\t") ; \
-        tabulate([["foo", 1], ["spam", 23]], tablefmt=tsv) == u'foo \\t 1\\nspam\\t23'
+        tabulate([["foo", 1], ["spam", 23]], tablefmt=tsv) == 'foo \\t 1\\nspam\\t23'
     True
 
     """
@@ -249,7 +249,7 @@ def _type(string, has_invisible=True):
     True
     >>> _type("1") is type(1)
     True
-    >>> _type(u'\x1b[31m42\x1b[0m') is type(42)
+    >>> _type('\x1b[31m42\x1b[0m') is type(42)
     True
     >>> _type('\x1b[31m42\x1b[0m') is type(42)
     True
@@ -304,36 +304,36 @@ def _afterpoint(string):
 def _padleft(width, s, has_invisible=True):
     """Flush right.
 
-    >>> _padleft(6, u'\u044f\u0439\u0446\u0430') == u'  \u044f\u0439\u0446\u0430'
+    >>> _padleft(6, '\u044f\u0439\u0446\u0430') == '  \u044f\u0439\u0446\u0430'
     True
 
     """
     iwidth = width + len(s) - len(_strip_invisible(s)) if has_invisible else width
-    fmt = u"{0:>%ds}" % iwidth
+    fmt = "{0:>%ds}" % iwidth
     return fmt.format(s)
 
 
 def _padright(width, s, has_invisible=True):
     """Flush left.
 
-    >>> _padright(6, u'\u044f\u0439\u0446\u0430') == u'\u044f\u0439\u0446\u0430  '
+    >>> _padright(6, '\u044f\u0439\u0446\u0430') == '\u044f\u0439\u0446\u0430  '
     True
 
     """
     iwidth = width + len(s) - len(_strip_invisible(s)) if has_invisible else width
-    fmt = u"{0:<%ds}" % iwidth
+    fmt = "{0:<%ds}" % iwidth
     return fmt.format(s)
 
 
 def _padboth(width, s, has_invisible=True):
     """Center string.
 
-    >>> _padboth(6, u'\u044f\u0439\u0446\u0430') == u' \u044f\u0439\u0446\u0430 '
+    >>> _padboth(6, '\u044f\u0439\u0446\u0430') == ' \u044f\u0439\u0446\u0430 '
     True
 
     """
     iwidth = width + len(s) - len(_strip_invisible(s)) if has_invisible else width
-    fmt = u"{0:^%ds}" % iwidth
+    fmt = "{0:^%ds}" % iwidth
     return fmt.format(s)
 
 
@@ -412,7 +412,7 @@ def _column_type(strings, has_invisible=True):
     True
     >>> _column_type(["1", "2.3", "four"]) is _text_type
     True
-    >>> _column_type(["four", u'\u043f\u044f\u0442\u044c']) is _text_type
+    >>> _column_type(["four", '\u043f\u044f\u0442\u044c']) is _text_type
     True
     >>> _column_type([None, "brux"]) is _text_type
     True
@@ -427,14 +427,14 @@ def _column_type(strings, has_invisible=True):
     return reduce(_more_generic, types, int)
 
 
-def _format(val, valtype, floatfmt, missingval=u""):
+def _format(val, valtype, floatfmt, missingval=""):
     """Format a value accoding to its type.
 
     Unicode is supported:
 
-    >>> hrow = [u'\u0431\u0443\u043a\u0432\u0430', u'\u0446\u0438\u0444\u0440\u0430'] ; \
-        tbl = [[u'\u0430\u0437', 2], [u'\u0431\u0443\u043a\u0438', 4]] ; \
-        good_result = u'\\u0431\\u0443\\u043a\\u0432\\u0430      \\u0446\\u0438\\u0444\\u0440\\u0430\\n-------  -------\\n\\u0430\\u0437             2\\n\\u0431\\u0443\\u043a\\u0438           4' ; \
+    >>> hrow = ['\u0431\u0443\u043a\u0432\u0430', '\u0446\u0438\u0444\u0440\u0430'] ; \
+        tbl = [['\u0430\u0437', 2], ['\u0431\u0443\u043a\u0438', 4]] ; \
+        good_result = '\\u0431\\u0443\\u043a\\u0432\\u0430      \\u0446\\u0438\\u0444\\u0440\\u0430\\n-------  -------\\n\\u0430\\u0437             2\\n\\u0431\\u0443\\u043a\\u0438           4' ; \
         tabulate(tbl, headers=hrow) == good_result
     True
 
@@ -443,13 +443,13 @@ def _format(val, valtype, floatfmt, missingval=u""):
         return missingval
 
     if valtype in [int, _text_type]:
-        return u"{0}".format(val)
+        return "{0}".format(val)
     elif valtype is _binary_type:
         return _text_type(val, "ascii")
     elif valtype is float:
         return format(float(val), floatfmt)
     else:
-        return u"{0}".format(val)
+        return "{0}".format(val)
 
 
 def _align_header(header, alignment, width):
@@ -458,7 +458,7 @@ def _align_header(header, alignment, width):
     elif alignment == "center":
         return _padboth(width, header)
     elif not alignment:
-        return u"{0}".format(header)
+        return "{0}".format(header)
     else:
         return _padleft(width, header)
 
@@ -532,14 +532,14 @@ def _normalize_tabular_data(tabular_data, headers):
        nhs = len(headers)
        ncols = len(rows[0])
        if nhs < ncols:
-           headers = [u""]*(ncols - nhs) + headers
+           headers = [""]*(ncols - nhs) + headers
 
     return rows, headers
 
 
 def tabulate(tabular_data, headers=[], tablefmt="simple",
              floatfmt="g", numalign="decimal", stralign="left",
-             missingval=u""):
+             missingval=""):
     """Format a fixed width table for pretty printing.
 
     >>> print(tabulate([[1, 2.34], [-56, "8.999"], ["2", "10001"]]))
@@ -740,8 +740,8 @@ def tabulate(tabular_data, headers=[], tablefmt="simple",
 
     # optimization: look for ANSI control codes once,
     # enable smart width functions only if a control code is found
-    plain_text = u'\n'.join(['\t'.join(map(_text_type, headers))] + \
-                            [u'\t'.join(map(_text_type, row)) for row in list_of_lists])
+    plain_text = '\n'.join(['\t'.join(map(_text_type, headers))] + \
+                            ['\t'.join(map(_text_type, row)) for row in list_of_lists])
     has_invisible = re.search(_invisible_codes, plain_text)
     if has_invisible:
         width_fn = _visible_width
@@ -806,7 +806,7 @@ def _build_line(colwidths, colaligns, linefmt):
 
 def _pad_row(cells, padding):
     if cells:
-        pad = u" "*padding
+        pad = " "*padding
         padded_cells = [pad + cell + pad for cell in cells]
         return padded_cells
     else:
